pub struct WriteMarkdown {
dir: PathBuf,
}Expand description
Write a full markdown file for example with design specifications developed in a conversation with the user, to save for later viewing.
Fields
dir: PathBufDirectory where to store markdown output files
Implementations